@@ -1,6 +1,6 @@
 <?php
 /**
- * The Auth_gollem:: class provides an Gollem implementation of the Horde
+ * The Auth_gollem:: class provides a Gollem implementation of the Horde
  * authentication system.
  *
  * Required parameters:<pre>
@@ -9,9 +9,9 @@
  * Optional parameters:<pre>
  *   None.</pre>
  *
- * $Horde: gollem/lib/Auth/gollem.php,v 1.18.2.5 2007/01/02 13:54:53 jan Exp $
+ * $Horde: gollem/lib/Auth/gollem.php,v 1.18.2.7 2009/01/06 15:23:54 jan Exp $
  *
- * Copyright 2004-2007 Michael Slusarz <slusarz@curecanti.org>
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -95,7 +95,12 @@ class Auth_gollem extends Auth {
             return false;
         }
 
+        // Allocate a global VFS object
         $GLOBALS['gollem_vfs'] = &Gollem::getVFSOb($_SESSION['gollem']['backend_key']);
+        if (is_a($GLOBALS['gollem_vfs'], 'PEAR_Error')) {
+            Horde::fatal($GLOBALS['gollem_vfs']);
+        }
+
         $valid = $GLOBALS['gollem_vfs']->checkCredentials();
         if (is_a($valid, 'PEAR_Error')) {
             $msg = $valid->getMessage();
