@@ -1,43 +1,36 @@
 <?php
-
-// Sort types
-
 /**
- * Sort by file type.
+ * $Horde: gollem/lib/Gollem.php,v 1.172.2.28 2009/03/18 22:18:22 jan Exp $
+ *
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
+ *
+ * See the enclosed file COPYING for license information (GPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @package Gollem
  */
+
+/** Sort by file type. */
 define('GOLLEM_SORT_TYPE', 0);
-/**
- * Sort by file name.
- */
+
+/** Sort by file name. */
 define('GOLLEM_SORT_NAME', 1);
-/**
- * Sort by file date.
- */
+
+/** Sort by file date. */
 define('GOLLEM_SORT_DATE', 2);
-/**
- * Sort by file size.
- */
+
+/** Sort by file size. */
 define('GOLLEM_SORT_SIZE', 3);
 
-// Sort direction
-
-/**
- * Sort ascending.
- */
+/** Sort ascending. */
 define('GOLLEM_SORT_ASCEND', 0);
-/**
- * Sort descending.
- */
+
+/** Sort descending. */
 define('GOLLEM_SORT_DESCEND', 1);
 
 /**
  * Gollem Base Class.
  *
- * $Horde: gollem/lib/Gollem.php,v 1.172.2.20 2006/05/19 17:14:06 slusarz Exp $
- *
- * See the enclosed file COPYING for license information (GPL).  If you
- * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
- *
  * @author  Max Kalika <max@horde.org>
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @package Gollem
@@ -90,7 +83,7 @@ class Gollem {
     function canAutoLogin($key = null, $force = false)
     {
         $auto_server = Gollem::getPreferredBackend();
-        if (is_null($key)) {
+        if ($key === null) {
             $key = $auto_server;
         }
 
@@ -131,7 +124,7 @@ class Gollem {
     function changeDir()
     {
         $dir = Util::getFormData('dir');
-        if (!is_null($dir)) {
+        if ($dir !== null) {
             if (strpos($dir, '/') !== 0) {
                 $dir = $GLOBALS['gollem_be']['dir'] . '/' . $dir;
             }
@@ -299,30 +292,78 @@ class Gollem {
      */
     function listFolder($dir)
     {
-        $files = $GLOBALS['gollem_vfs']->listFolder($dir, isset($GLOBALS['gollem_be']['filter']) ? $GLOBALS['gollem_be']['filter'] : null, $GLOBALS['prefs']->getValue('show_dotfiles'));
-        if (!is_a($files, 'PEAR_Error')) {
-            switch ($GLOBALS['prefs']->getValue('sortby')) {
-            case GOLLEM_SORT_TYPE:
-                usort($files, array('Gollem', '_sortType'));
-                break;
+        global $conf;
 
-            case GOLLEM_SORT_NAME:
-                usort($files, array('Gollem', '_sortName'));
-                break;
+        if (!empty($conf['foldercache']['use_cache']) &&
+            !empty($conf['cache']['driver']) &&
+            ($conf['cache']['driver'] != 'none')) {
+            require_once 'Horde/Cache.php';
+            require_once 'Horde/Serialize.php';
+            $key = Gollem::_getCacheID($dir);
 
-            case GOLLEM_SORT_DATE:
-                usort($files, array('Gollem', '_sortDate'));
-                break;
-
-            case GOLLEM_SORT_SIZE:
-                usort($files, array('Gollem', '_sortSize'));
-                break;
+            $cache = &Horde_Cache::singleton($conf['cache']['driver'], Horde::getDriverConfig('cache', $conf['cache']['driver']));
+            $res = $cache->get($key, $conf['foldercache']['lifetime']);
+            if ($res !== false) {
+                $res = Horde_Serialize::unserialize($res, SERIALIZE_BASIC);
+                if (is_array($res)) {
+                    return $res;
+                }
             }
         }
 
+        $files = $GLOBALS['gollem_vfs']->listFolder($dir, isset($GLOBALS['gollem_be']['filter']) ? $GLOBALS['gollem_be']['filter'] : null, $GLOBALS['prefs']->getValue('show_dotfiles'));
+        if (!is_a($files, 'PEAR_Error')) {
+            $sortcols = array(
+                GOLLEM_SORT_TYPE => '_sortType',
+                GOLLEM_SORT_NAME => '_sortName',
+                GOLLEM_SORT_DATE => '_sortDate',
+                GOLLEM_SORT_SIZE => '_sortSize',
+            );
+            usort($files, array('Gollem', $sortcols[$GLOBALS['prefs']->getValue('sortby')]));
+        }
+
+        if (isset($cache)) {
+            require_once 'Horde/Serialize.php';
+            $cache->set($key, Horde_Serialize::serialize($files, SERIALIZE_BASIC), $conf['foldercache']['lifetime']);
+        }
+
         return $files;
     }
 
+    /**
+     * Generate the Cache ID for a directory.
+     *
+     * @access private
+     * @since Gollem 1.1
+     *
+     * @param string $dir  The directory name.
+     */
+    function _getCacheID($dir)
+    {
+        global $prefs;
+        return implode('|', array(Auth::getAuth(), $_SESSION['gollem']['backend_key'], $prefs->getValue('show_dotfiles'), $prefs->getValue('sortdirsfirst'), $prefs->getValue('sortby'), $prefs->getValue('sortdir'), $dir));
+    }
+
+    /**
+     * Expire a folder cache entry.
+     *
+     * @since Gollem 1.1
+     *
+     * @param string $dir  The directory name.
+     */
+    function expireCache($dir)
+    {
+        global $conf;
+
+        if (!empty($conf['foldercache']['use_cache']) &&
+            !empty($conf['cache']['driver']) &&
+            ($conf['cache']['driver'] != 'none')) {
+            require_once 'Horde/Cache.php';
+            $cache = &Horde_Cache::singleton($conf['cache']['driver'], Horde::getDriverConfig('cache', $conf['cache']['driver']));
+            $cache->expire(Gollem::_getCacheID($dir));
+        }
+    }
+
     /**
      * Generate correct subdirectory links.
      *
@@ -592,6 +633,9 @@ class Gollem {
 
         /* Read the source data. */
         $data = $from_be->read($dir, $name);
+        if (is_a($data, 'PEAR_Error')) {
+            return $data;
+        }
 
         /* Write the target data. */
         $res = $to_be->writeData($newdir, $name, $data);
@@ -700,18 +744,15 @@ class Gollem {
                               $backend = null)
     {
         $userID = Auth::getAuth();
-        if (is_null($backend)) {
+        if ($backend === null) {
             $backend = $_SESSION['gollem']['backend_key'];
         }
 
         switch ($filter) {
         case 'backend':
             $backendTag = 'gollem:backends:' . $backend;
-            if (!$GLOBALS['perms']->exists($backendTag) ||
-                $GLOBALS['perms']->hasPermission($backendTag, $userID, $permission)) {
-                return true;
-            }
-            break;
+            return (!$GLOBALS['perms']->exists($backendTag) ||
+                    $GLOBALS['perms']->hasPermission($backendTag, $userID, $permission));
         }
 
         return false;
@@ -729,14 +770,15 @@ class Gollem {
     {
         $label = array();
         $root_dir = Gollem::getRoot();
+        $root_dir_name = $_SESSION['gollem']['backends'][$_SESSION['gollem']['backend_key']]['name'];
 
         if ($currdir == $root_dir) {
-            $label[] = '[' . _("Root") . ']';
+            $label[] = '[' . $root_dir_name . ']';
         } else {
             $parts = explode('/', $currdir);
             $parts_count = count($parts);
 
-            $label[] = Horde::link(Util::addParameter($url, 'dir', $root_dir), sprintf(_("Up to %s"), _("Root"))) . '[' . _("Root") . ']</a>';
+            $label[] = Horde::link(Util::addParameter($url, 'dir', $root_dir), sprintf(_("Up to %s"), $root_dir_name)) . '[' . $root_dir_name . ']</a>';
 
             for ($i = 1; $i <= $parts_count; $i++) {
                 $part = array_slice($parts, 0, $i);
@@ -766,29 +808,20 @@ class Gollem {
     {
         require_once 'Horde/Menu.php';
 
-        $menu = &new Menu();
-        $menu->add(Util::addParameter(Horde::applicationUrl('manager.php'), 'dir', Gollem::getHome()), _("Home"), 'home.png');
-
-        if (strpos($_SERVER['PHP_SELF'], 'manager.php') !== false) {
-            if (Gollem::checkPermissions('backend', PERMS_EDIT)) {
-                $menu->add('#', _("Create Folder"), 'mkdir.png', null, '', 'createFolder(); return false;');
-            }
-            if (Gollem::checkPermissions('backend', PERMS_READ)) {
-                $menu->add('#', _("Change Folder"), 'cd.png', null, '', 'changeDirectory(); return false;');
-            }
-        }
+        $menu = new Menu();
+        $menu->add(Util::addParameter(Horde::applicationUrl('manager.php'), 'dir', Gollem::getHome()), _("_My Home"), 'folder_home.png');
 
         if (!empty($_SESSION['gollem'])) {
             $backend_key = $_SESSION['gollem']['backend_key'];
             if (Auth::isAdmin()) {
-                $menu->add(Util::addParameter(Horde::applicationUrl('permissions.php'), 'backend', $backend_key), _("Permissions"), 'administration.png', $GLOBALS['registry']->getImageDir('horde'));
+                $menu->add(Util::addParameter(Horde::applicationUrl('permissions.php'), 'backend', $backend_key), _("_Permissions"), 'perms.png', $GLOBALS['registry']->getImageDir('horde'));
             }
 
             if ($_SESSION['gollem']['hasquota'] &&
                 ($_SESSION['gollem']['backends'][$backend_key]['quota_val'] != -1)) {
                 if ($GLOBALS['browser']->hasFeature('javascript')) {
-                    Horde::addScriptFile('open_quota_win.js', 'gollem');
-                    $quota_url = 'javascript:open_quota_win(\'' . addslashes('backend=' . $backend_key) . '\');';
+                    Horde::addScriptFile('popup.js');
+                    $quota_url = "javascript:popup_gollem('" . Horde::applicationUrl('quota.php') . "',300,300,'" . addslashes('backend=' . $backend_key) . "');";
                 } else {
                     $quota_url = Util::addParameter(Horde::applicationUrl('quota.php'), 'backend', $backend_key);
                 }
@@ -810,8 +843,7 @@ class Gollem {
      */
     function menu()
     {
-        require_once 'Horde/Template.php';
-        $t = &new Horde_Template();
+        $t = new Gollem_Template();
 
         $t->set('forminput', Util::formInput());
         $t->set('be_select', Gollem::backendSelect(), true);
@@ -907,7 +939,7 @@ class Gollem {
     function realPath($path)
     {
         /* Standardize on UNIX directory separators. */
-        if (substr(PHP_OS, 0, 3) == 'WIN') {
+        if (!strncasecmp(PHP_OS, 'WIN', 3)) {
             $path = str_replace('\\', '/', $path);
         }
 
@@ -943,14 +975,35 @@ class Gollem {
      *
      * @return object  The Horde_VFS object requested.
      */
-    function &getVFSOb($backend_key)
+    function &getVFSOb($backend_key, $params = array())
     {
-        $be_config = &$_SESSION['gollem']['backends'][$backend_key];
-        $params = $be_config['params'];
-        if (!empty($params['password'])) {
-            $params['password'] = Secret::read(Secret::getKey('gollem'), $params['password']);
+        if (isset($_SESSION['gollem']['backends'][$backend_key])) {
+            $be_config = &$_SESSION['gollem']['backends'][$backend_key];
+        } else {
+            $be_config = $GLOBALS['gollem_backends'][$backend_key];
         }
+        if (!count($params)) {
+            $params = $be_config['params'];
+            if (!empty($params['password'])) {
+                $params['password'] = Secret::read(Secret::getKey('gollem'), $params['password']);
+            }
+        }
+
+        // Create VFS object
         $ob = &VFS::singleton($be_config['driver'], $params);
+        if (is_a($ob, 'PEAR_Error')) {
+            return $ob;
+        }
+
+        // Enable logging within VFS
+        $logger = &Horde::getLogger();
+        if ($logger !== false) {
+            // TODO: No need to do this check as of Horde 3.2
+            if (!is_a($logger, 'Log')) {
+                Horde::fatal(PEAR::raiseError('An error has occurred. Furthermore, Horde encountered an error attempting to log this error. Please check your Horde logging configuration in horde/config/conf.php.'), __FILE__, __LINE__, false);
+            }
+            $ob->setLogger($logger, $GLOBALS['conf']['log']['priority']);
+        }
 
         if (!isset($be_config['quota_val'])) {
             /* Only set quota information when we are finished with session
@@ -985,7 +1038,7 @@ class Gollem {
             }
         } elseif ($be_config['quota_val'] > -1) {
             $ob->setQuota($be_config['quota_val'], $be_config['quota_metric']);
-            $ob->setQuotaRoot(Gollem::getRoot());
+            $ob->setQuotaRoot($be_config['root']);
         }
 
         return $ob;
@@ -1041,4 +1094,126 @@ class Gollem {
         return $backends;
     }
 
+    /**
+     * Add inline javascript to the output buffer.
+     *
+     * @since Gollem 1.1
+     *
+     * @param string $script  The script text to add.
+     *
+     * @return string  The javascript text to output, or empty if the page
+     *                 headers have not yet been sent.
+     */
+    function addInlineScript($script)
+    {
+        $script = trim($script);
+        if (empty($script)) {
+            return;
+        }
+
+        if (!isset($GLOBALS['__gollem_inline_script'])) {
+            $GLOBALS['__gollem_inline_script'] = array();
+        }
+        $GLOBALS['__gollem_inline_script'][] = $script;
+
+        // If headers have already been sent, we need to output a
+        // <script> tag directly.
+        if (ob_get_length() || headers_sent()) {
+            Gollem::outputInlineScript();
+        }
+    }
+
+    /**
+     * Print inline javascript to the output buffer.
+     *
+     * @since Gollem 1.1
+     *
+     * @return string  The javascript text to output.
+     */
+    function outputInlineScript()
+    {
+        if (!empty($GLOBALS['__gollem_inline_script'])) {
+            echo '<script type="text/javascript">//<![CDATA[' . "\n";
+            foreach ($GLOBALS['__gollem_inline_script'] as $val) {
+                echo $val . "\n";
+            }
+            echo "//]]></script>\n";
+        }
+
+        $GLOBALS['__gollem_inline_script'] = array();
+    }
+
+    /**
+     * Cleans a path presented to Gollem's browse API call.
+     *
+     * This will remove:
+     * - leading '/'
+     * - leading 'gollem'
+     * - trailing '/'
+     * The desired end result is the path including VFS backend.
+     *
+     * @param string $path  Path as presented to Gollem API.
+     *
+     * @return string  Cleaned path as described above.
+     */
+    function stripAPIPath($path)
+    {
+        // Strip leading '/'
+        if (substr($path, 0, 1) == '/') {
+            $path = substr($path, 1);
+        }
+        // Remove 'gollem' from path
+        if (substr($path, 0, 6) == 'gollem') {
+            $path = substr($path, 6);
+        }
+        // Remove leading '/'
+        if (substr($path, 0, 1) == '/') {
+            $path = substr($path, 1);
+        }
+        // Remove trailing '/'
+        if (substr($path, -1) == '/') {
+            $path = substr($path, 0, -1);
+        }
+        return $path;
+    }
+
+    /**
+     * Convert a Gollem path into a URL encoded string, but keep '/'.
+     * This allows for proper PATH_INFO path parsing.
+     * Special care is taken to handle "+" and " ".
+     *
+     * @since Gollem 1.1
+     *
+     * @param string $path  Path to be urlencode()d.
+     *
+     * @return string  URL-encoded string with '/' preserved.
+     */
+    function pathEncode($path)
+    {
+         // TODO: Must use str_replace here instead of str_ireplace which is
+         // PHP5-only.
+         return str_replace(array('%2F', '%2f'), '/', rawurlencode($path));
+     }
+
+     /**
+      * Take a fully qualified and break off the file or directory name.
+      * This pair is used for the input to many VFS library functions.
+      *
+      * @param string $fullpath   Path to be split.
+      *
+      * @return array  Array of ($path, $name)
+      */
+     function getVFSPath($fullpath)
+     {
+        // Convert the path into VFS's ($path, $name) convention
+        $i = strrpos($fullpath, '/');
+        if ($i !== false) {
+            $path = substr($fullpath, 0, $i);
+            $name = substr($fullpath, $i + 1);
+        } else {
+            $name = $fullpath;
+            $path = '';
+        }
+        return array($name, $path);
+     }
 }
