@@ -2,11 +2,9 @@
 /**
  * Functions required to start a Gollem session.
  *
- * $Horde: gollem/lib/Session.php,v 1.34.2.5 2007/01/02 13:54:52 jan Exp $
+ * $Horde: gollem/lib/Session.php,v 1.34.2.8 2009/01/06 15:23:54 jan Exp $
  *
- * Copyright 1999-2007 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 2000-2007 Max Kalika <max@horde.org>
- * Copyright 2004-2007 Michael Slusarz <slusarz@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -92,7 +90,7 @@ class Gollem_Session {
         /* Set username now. Don't set the current username if the backend
          * already has a username defined. */
         if (empty($ptr['params']['username'])) {
-            $ptr['params']['username'] = (is_null($user)) ? Auth::getBareAuth() : $user;
+            $ptr['params']['username'] = ($user === null) ? Auth::getBareAuth() : $user;
         }
 
         /* Set password now. The password should always be encrypted within
@@ -100,7 +98,9 @@ class Gollem_Session {
         if (!empty($ptr['params']['password'])) {
             $pass = $ptr['params']['password'];
         }
-        if (!is_null($pass)) {
+        if ($pass === null) {
+            $ptr['params']['password'] = null;
+        } else {
             $ptr['params']['password'] = Secret::write(Secret::getKey('gollem'), $pass);
         }
 
