@@ -15,16 +15,16 @@
  *   $gollem_be - A link to the current backend parameters in the session
  *   $gollem_vfs - A link to the current VFS object for the active backend
  *
- * $Horde: gollem/lib/base.php,v 1.60.2.3 2007/02/16 09:12:28 slusarz Exp $
+ * $Horde: gollem/lib/base.php,v 1.60.2.4 2008/10/09 20:54:42 jan Exp $
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  */
 
 // Check for a prior definition of HORDE_BASE (perhaps by an
 // auto_prepend_file definition for site customization).
 if (!defined('HORDE_BASE')) {
-    @define('HORDE_BASE', dirname(__FILE__) . '/../..');
+    define('HORDE_BASE', dirname(__FILE__) . '/../..');
 }
 
 // Load the Horde Framework core, and set up inclusion paths.
@@ -44,22 +44,24 @@ if (is_a(($pushed = $registry->pushApp('gollem', !defined('AUTH_HANDLER'))), 'PE
     Horde::fatal($pushed, __FILE__, __LINE__, false);
 }
 $conf = &$GLOBALS['conf'];
-@define('GOLLEM_TEMPLATES', $registry->get('templates'));
+define('GOLLEM_TEMPLATES', $registry->get('templates'));
 
 // Notification system.
 $notification = &Notification::singleton();
 $notification->attach('status');
 
 // Find the base file path of Gollem.
-@define('GOLLEM_BASE', dirname(__FILE__) . '/..');
+if (!defined('GOLLEM_BASE')) {
+    define('GOLLEM_BASE', dirname(__FILE__) . '/..');
+}
 
-// Horde base libraries.
-require_once 'Horde/Help.php';
+// Horde libraries.
 require_once 'Horde/Secret.php';
 require_once 'VFS.php';
 
-// Gollem base library.
+// Gollem libraries.
 require_once GOLLEM_BASE . '/lib/Gollem.php';
+require_once GOLLEM_BASE . '/lib/Template.php';
 
 // If Gollem isn't responsible for Horde auth, and no one is logged into
 // Horde, redirect to the login screen.
@@ -72,6 +74,13 @@ if (!Util::nonInputVar('no_compress')) {
     Horde::compressOutput();
 }
 
+// Set the global $gollem_be variable to the current backend's parameters.
+if (empty($_SESSION['gollem']['backend_key'])) {
+    $GLOBALS['gollem_be'] = null;
+} else {
+    $GLOBALS['gollem_be'] = &$_SESSION['gollem']['backends'][$_SESSION['gollem']['backend_key']];
+}
+
 $authentication = Util::nonInputVar('authentication');
 if ($authentication !== 'none') {
     // If we've gotten to this point and have valid login credentials
@@ -86,15 +95,9 @@ if ($authentication !== 'none') {
         exit;
     }
 
+    // Check authentication and create $GLOBALS['gollem_vfs'] object
     Gollem::checkAuthentication($authentication);
 }
 
-// Set the global $gollem_be variable to the current backend's parameters.
-if (empty($_SESSION['gollem']['backend_key'])) {
-    $GLOBALS['gollem_be'] = null;
-} else {
-    $GLOBALS['gollem_be'] = &$_SESSION['gollem']['backends'][$_SESSION['gollem']['backend_key']];
-}
-
 // Load the backend list.
 Gollem::loadBackendList();
