@@ -2,20 +2,22 @@
 /**
  * Login screen for Gollem.
  *
- * $Horde: gollem/login.php,v 1.94.2.13 2007/01/02 13:54:52 jan Exp $
+ * $Horde: gollem/login.php,v 1.94.2.17 2009/03/19 14:43:18 jan Exp $
  *
- * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2007 Max Kalika <max@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Max Kalika <max@horde.org>
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
-function _notificationOutput(&$template)
+function _notificationOutput(&$t)
 {
     ob_start();
     $GLOBALS['notification']->notify(array('listeners' => 'status'));
-    $template->set('notification_output', ob_get_contents());
+    $t->set('notification_output', ob_get_contents());
     ob_end_clean();
 }
 
@@ -133,27 +135,30 @@ if ($gollem_auth) {
     Secret::setKey('auth');
 }
 /* Prepare the login template. */
-require_once 'Horde/Template.php';
-$template = &new Horde_Template();
-$template->setOption('gettext', true);
+$t = new Gollem_Template();
+$t->setOption('gettext', true);
 
 require_once 'Horde/Menu.php';
-$menu = &new Menu(HORDE_MENU_MASK_NONE);
-$template->set('menu', $menu->render(), true);
-$template->set('title', sprintf(_("%s Login"), $registry->get('name')));
+$menu = new Menu(HORDE_MENU_MASK_NONE);
+$t->set('menu', $menu->render(), true);
+$t->set('title', sprintf(_("%s Login"), $registry->get('name')));
 
 if (!$backend_key) {
     $backend_key = Gollem::getPreferredBackend();
     /* If there is no backend key defined, there is no available backends for
      * the current user. */
-    if (is_null($backend_key)) {
-        $reason = _("There are no backends available for the current user.");
+    if ($backend_key === null) {
+        $notification->push(_("There are no backends available for the current user."), 'horde.error');
         require GOLLEM_TEMPLATES . '/common-header.inc';
-        _notificationOutput($template);
-        $template->set('allowlogin', false, true);
-        echo $template->fetch(GOLLEM_TEMPLATES . '/login/login.html');
-        if (@is_readable(GOLLEM_BASE . '/config/motd.php')) {
-            require GOLLEM_BASE . '/config/motd.php';
+        _notificationOutput($t);
+        $t->set('allowlogin', false, true);
+        echo $t->fetch(GOLLEM_TEMPLATES . '/login/login.html');
+        if (is_callable(array('Horde', 'loadConfiguration'))) {
+            Horde::loadConfiguration('motd.php', null, null, true);
+        } else {
+            if (is_readable(GOLLEM_BASE . '/config/motd.php')) {
+                require GOLLEM_BASE . '/config/motd.php';
+            }
         }
         require $registry->get('templates', 'horde') . '/common-footer.inc';
         exit;
@@ -162,11 +167,12 @@ if (!$backend_key) {
 
 $login_vfs = array();
 foreach ($GLOBALS['gollem_backends'] as $key => $curBackend) {
-    $login_vfs[$key] = &VFS::singleton($curBackend['driver'], array_merge($curBackend['params'], array('user' => Auth::getAuth())));
+    $login_vfs[$key] = &Gollem::getVFSOb($key, array_merge($curBackend['params'], array('user' => Auth::getAuth())));
     if (is_a($login_vfs[$key], 'PEAR_Error')) {
         Horde::fatal($login_vfs[$key]);
     }
 }
+// Make the VFS global
 $GLOBALS['gollem_vfs'] = $login_vfs[$backend_key];
 
 /* If we only have one backend, and it doesn't require authentication, skip
@@ -180,13 +186,16 @@ if (!$logout_reason && !$autologin_fail) {
             $redirect_params['autologin'] = 1;
         }
     } elseif (Util::getFormData('change_backend') &&
-              empty($GLOBALS['gollem_backends'][$backend_key]['loginparams'])) {
+              Gollem::canAutoLogin($backend_key, true)) {
         $redirect_params['autologin'] = 1;
     }
 }
 
 if (!empty($redirect_params)) {
     $redirect_params += array('actionID' => 'login', 'backend_key' => $backend_key);
+    if ($url_param) {
+        $redirect_params['url'] = $url_param;
+    }
     $url = Util::addParameter(Horde::applicationUrl('redirect.php', true), $redirect_params, null, false);
     header('Location: ' . $url);
     exit;
@@ -200,10 +209,9 @@ if ($logout_reason && $gollem_auth && $conf['menu']['always']) {
     $notification->push('setFocus()', 'javascript');
 }
 
-$reason = $auth->getLogoutReasonString();
-
-/* Add some javascript. */
-Horde::addScriptFile('enter_key_trap.js', 'horde', true);
+if ($reason = $auth->getLogoutReasonString()) {
+    $notification->push(str_replace('<br />', ' ', $reason), 'horde.message');
+}
 
 /* Do we need to do IE version detection? */
 if (!Auth::getAuth() &&
@@ -213,31 +221,30 @@ if (!Auth::getAuth() &&
 }
 
 $choose_language = ($gollem_auth && !$prefs->isLocked('language'));
+$lang_url = null;
 if ($choose_language) {
     $lang_url = (!empty($url_param)) ? urlencode($url_param) : null;
 }
 
-require GOLLEM_TEMPLATES . '/common-header.inc';
-require_once GOLLEM_TEMPLATES . '/login/javascript.inc';
-
 $tabindex = 0;
-$template->set('allowlogin', true, true);
+$t->set('allowlogin', true, true);
 
-$template->set('action', Horde::url('redirect.php', false, -1, true));
-$template->set('gollem_auth', $gollem_auth, true);
-$template->set('form_input', Util::formInput());
-$template->set('actionid', $actionID);
-$template->set('load_frameset', ($gollem_auth) ? 1 : 0);
-$template->set('url', htmlspecialchars($url_param));
-$template->set('autologin', ($autologin || Gollem::canAutoLogin($backend_key, true)) ? 1 : 0);
-$template->set('clientcaps', !empty($ie_clientcaps), true);
-$template->set('backend_key', ($conf['backend']['backend_list'] != 'shown') ? $backend_key : null, true);
+$t->set('action', Horde::url('redirect.php', false, -1, true));
+$t->set('gollem_auth', $gollem_auth, true);
+$t->set('form_input', Util::formInput());
+$t->set('actionid', $actionID);
+$t->set('load_frameset', intval($gollem_auth));
+$t->set('url', htmlspecialchars($url_param));
+$t->set('autologin', ($autologin || Gollem::canAutoLogin($backend_key, true)) ? 1 : 0);
+$t->set('clientcaps', !empty($ie_clientcaps), true);
+$t->set('anchor_string', htmlspecialchars(Util::getFormData('anchor_string')));
+$t->set('backend_key', ($conf['backend']['backend_list'] != 'shown') ? $backend_key : null, true);
 
-_notificationOutput($template);
+_notificationOutput($t);
 
-$template->set('backend_shown', ($conf['backend']['backend_list'] == 'shown'), true);
-if ($template->get('backend_shown')) {
-    $template->set('shown_tabindex', ++$tabindex);
+$t->set('backend_shown', ($conf['backend']['backend_list'] == 'shown'), true);
+if ($t->get('backend_shown')) {
+    $t->set('shown_tabindex', ++$tabindex);
     $shown_array = array();
     foreach ($GLOBALS['gollem_backends'] as $key => $curBackend) {
         $shown_array[] = array(
@@ -246,12 +253,12 @@ if ($template->get('backend_shown')) {
             'val' => $key
         );
     }
-    $template->set('shown_array', $shown_array, true);
+    $t->set('shown_array', $shown_array, true);
 }
 
-$template->set('backend_hidden', ($conf['backend']['backend_list'] == 'hidden'), true);
-if ($template->get('backend_hidden')) {
-    $template->set('hidden_text', sprintf(_("Connect to: %s"), $GLOBALS['gollem_backends'][$backend_key]['name']));
+$t->set('backend_hidden', ($conf['backend']['backend_list'] == 'hidden'), true);
+if ($t->get('backend_hidden')) {
+    $t->set('hidden_text', sprintf(_("Connect to: %s"), $GLOBALS['gollem_backends'][$backend_key]['name']));
 }
 
 $loginparams = array();
@@ -265,7 +272,7 @@ if (!empty($GLOBALS['gollem_backends'][$backend_key]['loginparams'])) {
         );
     }
 }
-$template->set('loginparams', $loginparams);
+$t->set('loginparams', $loginparams);
 
 $log_creds = array();
 require GOLLEM_BASE . '/config/credentials.php';
@@ -282,11 +289,11 @@ foreach ($login_vfs[$backend_key]->getRequiredCredentials() as $credential) {
         );
     }
 }
-$template->set('log_creds', $log_creds);
+$t->set('log_creds', $log_creds);
 
-$template->set('choose_language', $choose_language, true);
+$t->set('choose_language', $choose_language, true);
 if ($choose_language) {
-    $template->set('langs_tabindex', ++$tabindex);
+    $t->set('langs_tabindex', ++$tabindex);
     $_SESSION['horde_language'] = NLS::select();
     $langs = array();
     foreach ($nls['languages'] as $key => $val) {
@@ -296,15 +303,31 @@ if ($choose_language) {
             'name' => $val
         );
     }
-    $template->set('langs', $langs, true);
+    $t->set('langs', $langs, true);
 }
 
-$template->set('login_tabindex', ++$tabindex);
-$template->set('login', _("Login"));
+$t->set('login_tabindex', ++$tabindex);
+$t->set('login', _("Login"));
 
-echo $template->fetch(GOLLEM_TEMPLATES . '/login/login.html');
+$js_code = array(
+    'var ie_clientcaps = ' . intval($t->get('clientcaps')),
+    'var gollem_auth = ' . intval($gollem_auth),
+    'var lang_url = ' . (is_null($lang_url) ? 'null' : '\'' . $lang_url . '\''),
+    'var nomenu = ' . intval(empty($conf['menu']['always'])),
+    'var reload_url = \'' . Util::addParameter(Horde::selfUrl(false, true, true), array('backend_key' => null), null, false) . '\'',
+);
 
-if (@is_readable(GOLLEM_BASE . '/config/motd.php')) {
-    require GOLLEM_BASE . '/config/motd.php';
+Horde::addScriptFile('prototype.js', 'gollem', true);
+Horde::addScriptFile('login.js', 'gollem', true);
+require GOLLEM_TEMPLATES . '/common-header.inc';
+Gollem::addInlineScript(implode(';', $js_code));
+echo $t->fetch(GOLLEM_TEMPLATES . '/login/login.html');
+
+if (is_callable(array('Horde', 'loadConfiguration'))) {
+    Horde::loadConfiguration('motd.php', null, null, true);
+} else {
+    if (is_readable(GOLLEM_BASE . '/config/motd.php')) {
+        require GOLLEM_BASE . '/config/motd.php';
+    }
 }
 require $registry->get('templates', 'horde') . '/common-footer.inc';
