@@ -1,23 +1,29 @@
 <?php
 /**
- * $Horde: gollem/manager.php,v 1.146.2.19 2007/01/02 13:54:52 jan Exp $
+ * $Horde: gollem/manager.php,v 1.146.2.23 2009/03/19 14:18:21 jan Exp $
  *
- * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2007 Max Kalika <max@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did notcan receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Max Kalika <max@horde.org>
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
 @define('GOLLEM_BASE', dirname(__FILE__));
 require_once GOLLEM_BASE . '/lib/base.php';
-require_once 'Horde/MIME/Part.php';
-require_once 'Horde/Template.php';
+require_once 'Horde/Help.php';
 
 $actionID = Util::getFormData('actionID');
 $backkey = $_SESSION['gollem']['backend_key'];
 $old_dir = Gollem::getDir();
 
+/* Get permissions. */
+$delete_perms = Gollem::checkPermissions('backend', PERMS_DELETE);
+$edit_perms = Gollem::checkPermissions('backend', PERMS_EDIT);
+$read_perms = Gollem::checkPermissions('backend', PERMS_READ);
+
 /* Set directory. */
 if (is_a($result = Gollem::changeDir(), 'PEAR_Error')) {
     $notification->push($result);
@@ -26,7 +32,7 @@ if (is_a($result = Gollem::changeDir(), 'PEAR_Error')) {
 /* Run through the action handlers. */
 switch ($actionID) {
 case 'create_folder':
-    if (Gollem::checkPermissions('backend', PERMS_EDIT)) {
+    if ($edit_perms) {
         if ($new_folder = Util::getPost('new_folder')) {
             $result = Gollem::createFolder($old_dir, $new_folder);
             if (is_a($result, 'PEAR_Error')) {
@@ -39,12 +45,11 @@ case 'create_folder':
     break;
 
 case 'rename_items':
-    if (Gollem::checkPermissions('backend', PERMS_EDIT)) {
+    if ($edit_perms) {
         $new = explode('|', Util::getPost('new_names'));
         $old = explode('|', Util::getPost('old_names'));
         if (!empty($new) && !empty($old) && (count($new) == count($old))) {
-            $iMax = count($new);
-            for ($i = 0; $i < $iMax; $i++) {
+            for ($i = 0, $iMax = count($new); $i < $iMax; ++$i) {
                 $result = Gollem::renameItem($old_dir, $old[$i], $old_dir, $new[$i]);
                 if (is_a($result, 'PEAR_Error')) {
                     $notification->push($result->getMessage(), 'horde.error');
@@ -52,6 +57,7 @@ case 'rename_items':
                     $notification->push(sprintf(_("\"%s\" renamed to \"%s\""), $old[$i], $new[$i]), 'horde.success');
                 }
             }
+            Gollem::expireCache($old_dir);
         } else {
             $notification->push(_("Incorrect number of items."), 'horde.error');
         }
@@ -60,24 +66,35 @@ case 'rename_items':
 
 case 'chmod_modify':
 case 'delete_items':
-    if (Gollem::checkPermissions('backend', PERMS_DELETE)) {
+    if ($delete_perms) {
         $items = Util::getPost('items');
         if (is_array($items) && count($items)) {
             $chmod = Util::getPost('chmod');
             foreach ($items as $item) {
                 if (($actionID == 'chmod_modify') && $chmod) {
                     if (!is_a(Gollem::changePermissions(Gollem::getDir(), $item, $chmod), 'PEAR_Error')) {
+                        Gollem::expireCache($old_dir);
                         $notification->push(_("Chmod done: ") . $item, 'horde.success');
                     } else {
-                        $notification->push(sprintf(_("Cannot chmod %s"), $item), 'horde.error');
+                        $notification->push(sprintf(_("Cannot chmod %s: %s"), $item, $result->getMessage()), 'horde.error');
                     }
                 } elseif ($actionID == 'delete_items') {
-                    if (!is_a($result = Gollem::deleteFile($old_dir, $item), 'PEAR_Error')) {
-                        $notification->push(_("File deleted: ") . $item, 'horde.success');
-                    } elseif (!is_a($result = Gollem::deleteFolder($old_dir, $item), 'PEAR_Error')) {
-                        $notification->push(_("Folder removed: ") . $item, 'horde.success');
+                    if ($GLOBALS['gollem_vfs']->isFolder($old_dir, $item)) {
+                        $result = Gollem::deleteFolder($old_dir, $item);
+                        if (is_a($result, 'PEAR_Error')) {
+                            $notification->push(sprintf(_("Unable to delete folder %s: %s"), $item, $result->getMessage()), 'horde.error');
+                        } else {
+                            Gollem::expireCache($old_dir);
+                            $notification->push(_("Folder removed: ") . $item, 'horde.success');
+                        }
                     } else {
-                        $notification->push(sprintf(_("Cannot delete \"%s\": %s"), $item, $result->getMessage()), 'horde.error');
+                        $result = Gollem::deleteFile($old_dir, $item);
+                        if (is_a($result, 'PEAR_Error')) {
+                            $notification->push(sprintf(_("Unable to delete file %s: %s"), $item, $result->getMessage()), 'horde.error');
+                        } else {
+                            Gollem::expireCache($old_dir);
+                            $notification->push(_("File deleted: ") . $item, 'horde.success');
+                        }
                     }
                 }
             }
@@ -86,19 +103,20 @@ case 'delete_items':
     break;
 
 case 'upload_file':
-    if (Gollem::checkPermissions('backend', PERMS_EDIT)) {
-        for ($i = 1; $i <= count($_FILES); $i++) {
+    if ($edit_perms) {
+        for ($i = 1, $l = count($_FILES); $i <= $l; ++$i) {
             $val = 'file_upload_' . $i;
-            if (isset($_FILES[$val]) &&
-                ($_FILES[$val]['error'] != 4)) {
+            if (isset($_FILES[$val]) && ($_FILES[$val]['error'] != 4)) {
                 $res = Browser::wasFileUploaded($val);
                 if (!is_a($res, 'PEAR_Error')) {
-                    $res = Gollem::writeFile($old_dir, $_FILES[$val]['name'], $_FILES[$val]['tmp_name']);
+                    $filename = Util::dispelMagicQuotes($_FILES[$val]['name']);
+                    $res = Gollem::writeFile($old_dir, $filename, $_FILES[$val]['tmp_name']);
                 }
                 if (is_a($res, 'PEAR_Error')) {
                     $notification->push($res, 'horde.error');
                 } else {
-                    $notification->push(sprintf(_("File received: %s"), $_FILES[$val]['name']), 'horde.success');
+                    Gollem::expireCache($old_dir);
+                    $notification->push(sprintf(_("File received: %s"), $filename), 'horde.success');
                 }
             }
         }
@@ -107,8 +125,7 @@ case 'upload_file':
 
 case 'copy_items':
 case 'cut_items':
-    if (Gollem::checkPermissions('backend', PERMS_EDIT) &&
-        !empty($GLOBALS['gollem_be']['clipboard'])) {
+    if ($edit_perms && !empty($GLOBALS['gollem_be']['clipboard'])) {
         $action = ($actionID == 'copy_items') ? 'copy' : 'cut';
         $items = Util::getPost('items');
 
@@ -140,8 +157,7 @@ case 'cut_items':
 
 case 'clear_items':
 case 'paste_items':
-    if (Gollem::checkPermissions('backend', PERMS_EDIT) &&
-        !empty($GLOBALS['gollem_be']['clipboard'])) {
+    if ($edit_perms && !empty($GLOBALS['gollem_be']['clipboard'])) {
         $items = Util::getPost('items');
         if (is_array($items) && count($items)) {
             foreach ($items as $val) {
@@ -156,6 +172,10 @@ case 'paste_items':
                         if (is_a($res, 'PEAR_Error')) {
                             $notification->push(sprintf(_("Cannot paste \"%s\" (file cleared from clipboard): %s"), $file['name'], $res->getMessage()), 'horde.error');
                         } else {
+                            Gollem::expireCache($old_dir);
+                            if ($file['action'] == 'cut') {
+                                Gollem::expireCache($file['path']);
+                            }
                             $notification->push(sprintf(_("%s was successfully pasted."), $file['name'], $old_dir), 'horde.success');
                         }
                     }
@@ -200,24 +220,41 @@ if (is_a($list, 'PEAR_Error')) {
         $notification->push(sprintf(_("Permission denied to folder \"%s\": %s"), $currdir, $list->getMessage()), 'horde.error');
 
         $loc = strrpos($currdir, '/');
-        if ($loc !== false) {
-            Gollem::setDir(substr($currdir, 0, $loc));
-        } else {
-            Gollem::setDir(Gollem::getHome());
-        }
+        Gollem::setDir(($loc !== false) ? substr($currdir, 0, $loc) : Gollem::getHome());
         $currdir = Gollem::getDir();
         $list = Gollem::listFolder($currdir);
     }
 }
 
+$numitem = count($list);
+$title = $GLOBALS['gollem_be']['label'];
+
 /* Image links. */
-$download_img = Horde::img('download.png', _("Download"), null, $registry->getImageDir('horde'));
-$folder_img = Horde::img('manager/folder.png', _("folder"));
-$symlink_img = Horde::img('manager/symlink.png', _("symlink"));
+$image_dir = $registry->getImageDir('horde');
+$edit_img = Horde::img('edit.png', _("Edit"), null, $image_dir);
+$download_img = Horde::img('download.png', _("Download"), null, $image_dir);
+$folder_img = Horde::img('folder.png', _("folder"));
+$symlink_img = Horde::img('folder_symlink.png', _("symlink"));
+
+/* Init some form vars. */
+$page = Util::getFormData('page', 0);
+$filter = Util::getFormData('filter', '');
+if (isset($_SESSION['gollem']['filter']) &&
+    $_SESSION['gollem']['filter'] != $filter) {
+    $page = 0;
+}
+$_SESSION['gollem']['filter'] = $filter;
 
 /* Commonly used URLs. */
-$manager_url = Horde::applicationUrl('manager.php');
 $view_url = Horde::applicationUrl('view.php');
+$edit_url = Horde::applicationUrl('edit.php');
+$manager_url = Horde::applicationUrl('manager.php');
+
+$refresh_params = array('page' => $page);
+if ($filter) {
+    $refresh_params['filter'] = $filter;
+}
+$refresh_url = Util::addParameter($manager_url, $refresh_params);
 
 /* Get the list of copy/cut files in this directory. */
 $clipboard_files = array();
@@ -229,22 +266,12 @@ if (!empty($GLOBALS['gollem_be']['clipboard'])) {
     }
 }
 
-$title = $GLOBALS['gollem_be']['label'];
-Horde::addScriptFile('stripe.js', 'gollem', true);
-require GOLLEM_TEMPLATES . '/common-header.inc';
-Gollem::menu();
-Gollem::status();
-if ($browser->hasFeature('javascript')) {
-    require_once GOLLEM_TEMPLATES . '/manager/javascript.inc';
-    require_once $registry->get('templates', 'horde') . '/contents/open_view_win.js';
-}
-
 /* Read the columns to display from the preferences. */
 $sources = Gollem::displayColumns();
 $columns = isset($sources[$backkey]) ? $sources[$backkey] : $GLOBALS['gollem_be']['attributes'];
 
 /* Prepare the template. */
-$template = &new Horde_Template();
+$template = new Gollem_Template();
 $template->setOption('gettext', true);
 
 $attrib = $GLOBALS['gollem_vfs']->getModifiablePermissions();
@@ -262,15 +289,13 @@ foreach ($all_columns as $column) {
 $template->set('save', _("Save"));
 $template->set('cancel', _("Cancel"));
 $template->set('ok', _("OK"));
-$template->set('action', $manager_url);
+$template->set('action', $refresh_url);
 $template->set('forminput', Util::formInput());
 $template->set('dir', $currdir);
-$template->set('itemcount', (count($list) == 1) ? _("1 item") : sprintf(_("%d items"), count($list)));
 $template->set('navlink', Gollem::directoryNavLink($currdir, $manager_url));
-$template->set('refresh', Horde::link(Horde::selfUrl(), sprintf("%s %s", _("Refresh"), $GLOBALS['gollem_be']['label'])) . Horde::img('reload.png', sprintf("%s %s", _("Refresh"), htmlspecialchars($GLOBALS['gollem_be']['label'])), null, $registry->getImageDir('horde')) . '</a>');
+$template->set('refresh', Horde::link($refresh_url, sprintf("%s %s", _("Refresh"), $GLOBALS['gollem_be']['label']), '', '', '', '', '', array('id' => 'refreshimg')) . Horde::img('reload.png', sprintf("%s %s", _("Refresh"), htmlspecialchars($GLOBALS['gollem_be']['label'])), null, $image_dir) . '</a>');
 
-$edit_permissions = Gollem::checkPermissions('backend', PERMS_EDIT);
-$template->set('hasclipboard', !$edit_permissions || !empty($GLOBALS['gollem_be']['clipboard']), true);
+$template->set('hasclipboard', !$edit_perms || !empty($GLOBALS['gollem_be']['clipboard']), true);
 if (!$template->get('hasclipboard') ||
     empty($_SESSION['gollem']['clipboard'])) {
     $template->set('clipboard', null);
@@ -278,50 +303,87 @@ if (!$template->get('hasclipboard') ||
     $template->set('clipboard', Horde::link(Util::addParameter(Horde::applicationUrl('clipboard.php'), 'dir', $currdir), _("View Clipboard")) . Horde::img('clipboard.png', _("View Clipboard")) . '</a>');
 }
 
-if ($edit_permissions) {
+if ($edit_perms) {
     $template->set('perms_edit', true, true);
     $template->set('upload_file', _("Upload File(s)"));
     $template->set('upload_help', Help::link('gollem', 'file-upload'));
     $template->set('perms_chmod', in_array('permission', $columns), true);
+    $template->set('create_folder', Horde::link('#', _("Create Folder"), '', '', '', '', '', array('id' => 'createfolder')) . Horde::img('folder_create.png', _("Create Folder")) . '</a>');
 } else {
     $template->set('perms_edit', false, true);
     $template->set('perms_chmod', false, true);
 }
 
-if (count($list)) {
+if ($read_perms) {
+    $template->set('change_folder', Horde::link('#', _("Change Folder"), '', '', '', '', '', array('id' => 'changefolder')) . Horde::img('folder_goto.png', _("Change Folder")) . '</a>');
+}
+
+if ($numitem) {
     $template->set('list_count', true, true);
-    if (Gollem::checkPermissions('backend', PERMS_DELETE)) {
-        $template->set('perms_delete', true, true);
-    } else {
-        $template->set('perms_edit', false, true);
-    }
+    $template->set('perms_delete', $delete_perms);
     $template->set('actions_help', Help::link('gollem', 'file-actions'));
 } else {
     $template->set('list_count', false, true);
 }
 
 $icon_cache = array();
+$total = 0;
 
-if (is_array($list) &&
-    count($list) &&
-    Gollem::checkPermissions('backend', PERMS_READ)) {
+if (is_array($list) && $numitem && $read_perms) {
     $entry = array();
-    $i = $total_files = $total_folders = $total_size = 0;
+    $page_caption = '';
+
+    require_once 'Horde/MIME/Magic.php';
+    require_once 'Horde/MIME/Viewer.php';
+    if (is_callable(array('Horde', 'loadConfiguration'))) {
+        $result = Horde::loadConfiguration('mime_drivers.php', array('mime_drivers', 'mime_drivers_map'), 'horde');
+        extract($result);
+        $result = Horde::loadConfiguration('mime_drivers.php', array('mime_drivers', 'mime_drivers_map'), 'gollem');
+        require_once 'Horde/Array.php';
+        $mime_drivers = Horde_Array::array_merge_recursive_overwrite($mime_drivers, $result['mime_drivers']);
+        $mime_drivers_map = Horde_Array::array_merge_recursive_overwrite($mime_drivers_map, $result['mime_drivers_map']);
+    } else {
+        require HORDE_BASE . '/config/mime_drivers.php';
+        require GOLLEM_BASE . '/config/mime_drivers.php';
+    }
 
     $template->set('empty_dir', false, true);
 
-    foreach ($list as $key => $val) {
-        $item = array();
+    /* Set list min/max values */
+    $perpage = $prefs->getValue('perpage');
+    $min = $page * $perpage;
+    while ($min > $numitem) {
+        --$page;
+        $min = $page * $perpage;
+    }
+    $max = $min + $perpage;
 
-        $item['date'] = strftime($conf['manager']['date_format'], $val['date']);
-        $item['dl'] = false;
-        $item['group'] = (empty($val['group'])) ? '-' : $val['group'];
-        $item['name'] = htmlspecialchars($val['name']);
-        $item['on_clipboard'] = false;
-        $item['owner'] = (empty($val['owner'])) ? '-' : $val['owner'];
-        $item['perms'] = (empty($val['perms'])) ? '-' : $val['perms'];
-        $item['size'] = ($val['type'] == '**dir') ? '-' : number_format($val['size'], 0, '.', ',');
-        $item['type'] = $val['type'];
+    foreach ($list as $key => $val) {
+        /* Check if a filter is not empty and filter matches filename. */
+        if (strlen($filter) &&
+            !preg_match('/' . preg_quote($filter, '/') . '/', $val['name'])) {
+            continue;
+        }
+
+        /* Continue if item not in min/max range. */
+        if (($total++ < $min) || ($total > $max)) {
+            continue;
+        }
+
+        $item = array(
+            'date' => htmlspecialchars(strftime($prefs->getValue('date_format'), $val['date'])),
+            'date_sort' => (int)$val['date'],
+            'dl' => false,
+            'edit' => false,
+            'group' => empty($val['group']) ? '-' : htmlspecialchars($val['group']),
+            'name' => htmlspecialchars($val['name']),
+            'on_clipboard' => false,
+            'owner' => empty($val['owner']) ? '-' : htmlspecialchars($val['owner']),
+            'perms' => empty($val['perms']) ? '-' : htmlspecialchars($val['perms']),
+            'size' => ($val['type'] == '**dir') ? '-' : number_format($val['size'], 0, '.', ','),
+            'type' => htmlspecialchars($val['type']),
+            'type_sort' => ($val['type'] == '**dir') ? '' : htmlspecialchars($val['type']),
+        );
 
         $name = str_replace(' ', '&nbsp;', $item['name']);
 
@@ -337,10 +399,6 @@ if (is_array($list) &&
             $item['graphic'] = $folder_img;
         } else {
             if (empty($icon_cache[$val['type']])) {
-                require_once 'Horde/MIME/Magic.php';
-                require_once 'Horde/MIME/Viewer.php';
-                require_once HORDE_BASE . '/config/mime_drivers.php';
-                require_once GOLLEM_BASE . '/config/mime_drivers.php';
                 $icon_cache[$val['type']] = Horde::img(MIME_Viewer::getIcon(MIME_Magic::extToMIME($val['type'])), '', '', '');
             }
             $item['graphic'] = $icon_cache[$val['type']];
@@ -349,7 +407,7 @@ if (is_array($list) &&
         /* Create proper link. */
         switch ($val['type']) {
         case '**dir':
-            $url = Util::addParameter($manager_url, 'dir', Gollem::subdirectory($currdir, $val['name']));
+            $url = Util::addParameter($manager_url, array('dir' => Gollem::subdirectory($currdir, $val['name'])));
             $item['link'] = Horde::link($url) . '<strong>' . $name . '</strong></a>';
             break;
 
@@ -368,7 +426,7 @@ if (is_array($list) &&
                     $dir = $currdir;
                 }
 
-                $url = Util::addParameter($manager_url, 'dir', Gollem::subdirectory($dir, $name));
+                $url = Util::addParameter($manager_url, array('dir' => Gollem::subdirectory($dir, $name)));
                 $item['link'] = $item['name'] . ' -> <strong>' . Horde::link($url) . $val['link'] . '</a></strong>';
             } else {
                 $item['link'] = $item['name'] . ' -> ' . $val['link'];
@@ -376,55 +434,54 @@ if (is_array($list) &&
             break;
 
         default:
-            require_once 'Horde/MIME/Magic.php';
-            $mime_part = &new MIME_Part(MIME_Magic::extToMIME($val['type']), '');
+            $mime_type = MIME_Magic::extToMIME($val['type']);
+
+            // Edit link if possible.
+            if (strpos($mime_type, 'text/') === 0) {
+                $url = Util::addParameter($edit_url, array('actionID' => 'edit_file', 'type' => $val['type'], 'file' => $val['name'], 'dir' => $currdir, 'driver' => $GLOBALS['gollem_be']['driver']));
+                $item['edit'] = Horde::link($url, '', '', '_blank', 'popup(this.href); return false;') . $edit_img . '</a>';
+            }
+
             // We can always download files.
             $item['dl'] = Horde::link(Horde::downloadUrl($val['name'], array('actionID' => 'download_file', 'dir' => $currdir, 'driver' => $GLOBALS['gollem_be']['driver'], 'file' => $val['name'])), sprintf(_("Download %s"), $val['name'])) . $download_img . '</a>';
 
             // Try a view link.
             $url = Util::addParameter($view_url, array('actionID' => 'view_file', 'type' => $val['type'], 'file' => $val['name'], 'dir' => $currdir, 'driver' => $GLOBALS['gollem_be']['driver']));
-            $item['link'] = Horde::link('#', '', '', '', "view('$url', '" . $val['name'] . "'); return false;") . $name . '</a>';
+            $item['link'] = Horde::link($url, '', '', '_blank', 'popup(this.href); return false;') . $name . '</a>';
             break;
         }
 
-        if ($val['type'] != '**dir') {
-            $total_size += $val['size'];
-            $total_files++;
-        } else {
-            $total_folders++;
-        }
-
         $entry[] = $item;
     }
 
     /* Set up the variables needed for the header row. */
-    $manager_url = Horde::selfUrl();
     $sortby = $prefs->getValue('sortby');
     $sortdir = $prefs->getValue('sortdir');
 
-    $size = round($total_size / 1000);
-    if ($total_folders == 1) {
-        if ($total_files == 1) {
-            $size_caption = sprintf(_("1 Folder and 1 File (%s Kb)"), $size);
-        } else {
-            $size_caption = sprintf(_("1 Folder and %s Files (%s Kb)"), $total_files, $size);
-        }
-    } elseif ($total_files == 1) {
-        $size_caption = sprintf(_("%s Folders and 1 File (%s Kb)"), $total_folders, $size);
-    } else {
-        $size_caption = sprintf(_("%s Folders and %s Files (%s Kb)"), $total_folders, $total_files, $size);
+    if ($total) {
+        // Set start/end items (according to current page)
+        $start = ($page * $perpage) + 1;
+        $end = min($total, $start + $perpage - 1);
+
+        require_once 'Horde/Variables.php';
+        require_once 'Horde/UI/Pager.php';
+        $vars = Variables::getDefaultVariables();
+        $vars->set('page', $page);
+        $pager = new Horde_UI_Pager('page', $vars, array('num' => $total, 'url' => $refresh_url, 'page_count' => 10, 'perpage' => $perpage));
+        $page_caption = $pager->render();
     }
 
     $headers = array();
     foreach ($columns as $head) {
-        $hdr = array('class' => 'item', 'sort' => '');
+        $hdr = array('class' => '');
         $sort = null;
 
         switch ($head) {
         case 'type':
-            $hdr['width'] = '5%';
+            $hdr['width'] = '3%';
             $hdr['label'] = _("Type");
             $hdr['align'] = 'right';
+            $hdr['id'] = 's' . GOLLEM_SORT_TYPE;
             $sort = GOLLEM_SORT_TYPE;
             break;
 
@@ -432,19 +489,29 @@ if (is_array($list) &&
             $hdr['width'] = '57%';
             $hdr['label'] = _("Name");
             $hdr['align'] = 'left';
+            $hdr['id'] = 's' . GOLLEM_SORT_NAME;
             $sort = GOLLEM_SORT_NAME;
             break;
 
+        case 'edit':
+            $hdr['width'] = '1%';
+            $hdr['label'] = '&nbsp;';
+            $hdr['align'] = 'center';
+            $hdr['class'] = 'nosort';
+            break;
+
         case 'download':
             $hdr['width'] = '1%';
             $hdr['label'] = '&nbsp;';
             $hdr['align'] = 'center';
+            $hdr['class'] = 'nosort';
             break;
 
         case 'modified':
             $hdr['width'] = '7%';
             $hdr['label'] = _("Modified");
             $hdr['align'] = 'left';
+            $hdr['id'] = 's' . GOLLEM_SORT_DATE;
             $sort = GOLLEM_SORT_DATE;
             break;
 
@@ -452,6 +519,7 @@ if (is_array($list) &&
             $hdr['width'] = '7%';
             $hdr['label'] = _("Size");
             $hdr['align'] = 'right';
+            $hdr['id'] = 's' . GOLLEM_SORT_SIZE;
             $sort = GOLLEM_SORT_SIZE;
             break;
 
@@ -459,27 +527,29 @@ if (is_array($list) &&
             $hdr['width'] = '7%';
             $hdr['label'] = _("Permission");
             $hdr['align'] = 'right';
+            $hdr['class'] = 'nosort';
             break;
 
         case 'owner':
             $hdr['width'] = '7%';
             $hdr['label'] = _("Owner");
             $hdr['align'] = 'right';
+            $hdr['class'] = 'nosort';
             break;
 
         case 'group':
             $hdr['width'] = '7%';
             $hdr['label'] = _("Group");
             $hdr['align'] = 'right';
+            $hdr['class'] = 'nosort';
             break;
         }
 
-        if (!is_null($sort)) {
+        if ($sort !== null) {
             if ($sortby == $sort) {
-                $hdr['sort'] = '<a href="' . Util::addParameter($manager_url, array('actionID' => 'change_sortdir', 'sortdir' => abs(1 - $sortdir))) . '">' . Horde::img($sortdir ? 'za.png' : 'az.png', _("Sort Direction"), null, $registry->getImageDir('horde')) . '</a>&nbsp;';
-                $hdr['class'] = 'selected';
+                $hdr['class'] = ($sortdir ? 'sortup' : 'sortdown');
             }
-            $hdr['label'] = '<a href="' . Util::addParameter($manager_url, array('actionID' => 'change_sortby', 'sortby' => $sort)) .'">' . $hdr['label'] . '</a>';
+            $hdr['label'] = '<a href="' . Util::addParameter($refresh_url, array('actionID' => 'change_sortby', 'sortby' => $sort)) . '" class="sortlink">' . htmlspecialchars($hdr['label']) . '</a>';
         }
 
         $headers[] = $hdr;
@@ -488,12 +558,26 @@ if (is_array($list) &&
     /* Set up the template tags. */
     $template->set('headers', $headers, true);
     $template->set('entry', $entry, true);
-    $template->set('size_caption', $size_caption);
+    $template->set('page_caption', $page_caption);
+    $template->set('filter_val', $filter);
     $template->set('checkall', Horde::getAccessKeyAndTitle(_("Check _All/None")));
-
 } else {
     $template->set('empty_dir', true, true);
 }
+$template->set('itemcount', sprintf(ngettext(_("%d item"), _("%d items"), $total), $total));
 
+$js_code = array(
+    'var warn_recursive = ' . intval($GLOBALS['prefs']->getValue('recursive_deletes') == 'warn'),
+);
+
+Horde::addScriptFile('prototype.js', 'gollem', true);
+Horde::addScriptFile('manager.js', 'gollem', true);
+Horde::addScriptFile('popup.js', 'gollem', true);
+Horde::addScriptFile('tables.js', 'gollem', true);
+
+require GOLLEM_TEMPLATES . '/common-header.inc';
+Gollem::addInlineScript(implode(';', $js_code));
+Gollem::menu();
+Gollem::status();
 echo $template->fetch(GOLLEM_TEMPLATES . '/manager/manager.html');
 require $registry->get('templates', 'horde') . '/common-footer.inc';
