@@ -1,14 +1,39 @@
 <?php
 /**
- * $Horde: gollem/redirect.php,v 1.55.2.7 2007/01/02 13:54:52 jan Exp $
+ * $Horde: gollem/redirect.php,v 1.55.2.9 2009/01/06 15:23:53 jan Exp $
  *
- * Copyright 1999-2007 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2007 Max Kalika <max@horde.org>
+ * Copyright 1999-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Max Kalika <max@horde.org>
+ * @author Chuck Hagenbuch <chuck@horde.org>
  */
 
+/* Add anchor to outgoing URL. */
+function _addAnchor($url, $type)
+{
+    switch ($type) {
+    case 'param':
+        if (!empty($GLOBALS['url_anchor'])) {
+            $url .= '#' . $GLOBALS['url_anchor'];
+        }
+        break;
+
+    case 'url':
+        $anchor = Util::getFormData('anchor_string');
+        if (!empty($anchor)) {
+            $url .= '#' . $anchor;
+        } else {
+            return _addAnchor($url, 'param');
+        }
+        break;
+    }
+
+    return $url;
+}
+
 @define('AUTH_HANDLER', true);
 @define('GOLLEM_BASE', dirname(__FILE__));
 $authentication = 'none';
@@ -18,7 +43,7 @@ require GOLLEM_BASE . '/config/credentials.php';
 $actionID = Util::getFormData('actionID');
 $backend_key = Util::getFormData('backend_key');
 
-if (is_null($backend_key)) {
+if ($backend_key === null) {
     $autologin = Util::getFormData('autologin', false);
 } else {
     $autologin = Util::getFormData('autologin', Gollem::canAutoLogin($backend_key, true));
@@ -27,17 +52,25 @@ if (is_null($backend_key)) {
 $user = (empty($autologin)) ? Util::getPost('username') : Gollem::getAutologinID($backend_key);
 $pass = (empty($autologin)) ? Util::getPost('password') : Auth::getCredential('password');
 
+/* Get URL/Anchor strings now. */
+$url_anchor = null;
+$url_in = $url_form = Util::getFormData('url');
+if (($pos = strrpos($url_in, '#')) !== false) {
+    $url_anchor = substr($url_in, $pos + 1);
+    $url_in = substr($url_in, 0, $pos);
+}
+
 /* If we already have a session. */
 if (isset($_SESSION['gollem']) &&
     is_array($_SESSION['gollem']) &&
     ($_SESSION['gollem']['backend_key'] == $backend_key)) {
     /* Make sure that if a username was specified, it is the current
      * username. */
-    if ((is_null($user) ||
+    if ((($user === null) ||
          ($user == $GLOBALS['gollem_be']['params']['username'])) &&
-        (is_null($pass) ||
+        (($pass === null) ||
          ($pass == Secret::read(Secret::getKey('gollem'), $GLOBALS['gollem_be']['params']['password'])))) {
-        $url = Util::getFormData('url');
+        $url = $url_in;
         if (empty($url)) {
             $url = Horde::applicationUrl('manager.php', true);
         } elseif (!empty($actionID)) {
@@ -46,10 +79,10 @@ if (isset($_SESSION['gollem']) &&
 
         if (Util::getFormData('load_frameset')) {
             $full_url = Horde::applicationUrl($registry->get('webroot', 'horde') . '/index.php', true);
-            $url = Util::addParameter($full_url, 'url', $url, false);
+            $url = Util::addParameter($full_url, 'url', _addAnchor($url, 'param'), false);
         }
 
-        header('Refresh: 0; URL=' . $url);
+        header('Refresh: 0; URL=' . _addAnchor($url, 'url'));
         exit;
     } else {
         /* Disable the old session. */
@@ -71,13 +104,22 @@ if (Util::getFormData('gollem_loginform') ||
 
     /* Get the required parameters from the form data. */
     $args = array();
-    $postdata = array_keys($GLOBALS['gollem_backends'][$backend_key]['loginparams']);
+    if (isset($GLOBALS['gollem_backends'][$backend_key]['loginparams'])) {
+        $postdata = array_keys($GLOBALS['gollem_backends'][$backend_key]['loginparams']);
+    } else {
+        $postdata = array();
+    }
     if (empty($autologin)) {
-        $GLOBALS['gollem_vfs'] = &VFS::singleton($GLOBALS['gollem_backends'][$backend_key]['driver']);
+        // Allocate a global VFS object
+        $GLOBALS['gollem_vfs'] = &Gollem::getVFSOb($backend_key, array());
+        if (is_a($GLOBALS['gollem_vfs'], 'PEAR_Error')) {
+            Horde::fatal($GLOBALS['gollem_vfs']);
+        }
+
         $postdata = array_merge($postdata, $GLOBALS['gollem_vfs']->getRequiredCredentials());
     } else {
         /* We are attempting autologin.  If hordeauth is off, we need to make
-         * sure we are not trying to use horde auth info to login. */ 
+         * sure we are not trying to use horde auth info to login. */
         if (empty($GLOBALS['gollem_backends'][$backend_key]['hordeauth'])) {
             $pass = Util::getPost('password');
         }
@@ -101,9 +143,8 @@ if (Util::getFormData('gollem_loginform') ||
             $_SESSION['horde_language'] = $horde_language;
         }
 
-        $url = '';
-        if (Util::getFormData('url')) {
-            $url = Horde::url(Util::removeParameter(Util::getFormData('url'), session_name()), true);
+        if (!empty($url_in)) {
+            $url = Horde::url(Util::removeParameter($url_in, session_name()), true);
             if ($actionID) {
                 $url = Util::addParameter($url, 'actionID', $actionID, false);
             }
@@ -121,10 +162,10 @@ if (Util::getFormData('gollem_loginform') ||
 
     if (Util::getFormData('load_frameset')) {
         $full_url = Horde::applicationUrl($registry->get('webroot', 'horde') . '/index.php', true);
-        $url = Util::addParameter($full_url, 'url', $url, false);
+        $url = Util::addParameter($full_url, 'url', _addAnchor($url, 'param'), false);
     }
 
-    header('Refresh: 0; URL=' . $url);
+    header('Refresh: 0; URL=' . _addAnchor($url, 'url'));
     exit;
 }
 
