@@ -1,18 +1,19 @@
 <?php
 /**
- * $Horde: gollem/selectlist.php,v 1.13.2.4 2007/01/02 13:54:52 jan Exp $
+ * $Horde: gollem/selectlist.php,v 1.13.2.6 2009/01/06 15:23:53 jan Exp $
  *
- * Copyright 2004-2007 Michael Slusarz <slusarz@curecanti.org>
+ * Copyright 2004-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
- * did notcan receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file COPYING for license information (GPL). If you
+ * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Michael Slusarz <slusarz@horde.org>
  */
 
 @define('AUTH_HANDLER', true);
 @define('GOLLEM_BASE', dirname(__FILE__));
 $authentication = 'selectlist';
 require_once GOLLEM_BASE . '/lib/base.php';
-require_once 'Horde/Template.php';
 
 /* Set directory. */
 if (is_a($result = Gollem::changeDir(), 'PEAR_Error')) {
@@ -23,7 +24,7 @@ $currdir = Gollem::getDir();
 /* Create a new cache ID if one does not already exist. */
 $cacheid = Util::getFormData('cacheid');
 if (empty($cacheid)) {
-    $cacheid = substr(base_convert(microtime() . mt_rand(), 10, 36), -16);
+    $cacheid = uniqid(mt_rand(), true);
     $_SESSION['gollem']['selectlist'][$cacheid] = array();
 }
 
@@ -50,7 +51,7 @@ case 'select':
                 }
             }
         }
-        $filelist = array_unique($_SESSION['gollem']['selectlist'][$cacheid]['files']);
+        $filelist = array_keys(array_flip($_SESSION['gollem']['selectlist'][$cacheid]['files']));
     }
     break;
 }
@@ -71,8 +72,8 @@ if (is_a($info['list'], 'PEAR_Error')) {
 $info['title'] = htmlspecialchars($GLOBALS['gollem_be']['label']);
 
 /* Image links. */
-$folder_img = Horde::img('manager/folder.png', _("folder"));
-$symlink_img = Horde::img('manager/symlink.png', _("symlink"));
+$folder_img = Horde::img('folder.png', _("folder"));
+$symlink_img = Horde::img('folder_symlink.png', _("symlink"));
 
 /* Commonly used URLs. */
 $self_url = Horde::applicationUrl('selectlist.php');
@@ -83,28 +84,33 @@ $backkey = $_SESSION['gollem']['backend_key'];
 $list = $info['list'];
 $title = $info['title'];
 
+$js_code = array(
+    'var cacheid = \'' . $cacheid . '\'',
+    'var formid = \'' . $formid . '\'',
+);
+
+Horde::addScriptFile('selectlist.js', 'gollem', true);
 require GOLLEM_TEMPLATES . '/common-header.inc';
-require GOLLEM_TEMPLATES . '/selectlist/javascript.inc';
+Gollem::addInlineScript(implode(';', $js_code));
+Gollem::status();
 
 /* Set up the template object. */
-$template = new Horde_Template();
-$template->set('addbutton', _("Add"));
-$template->set('donebutton', _("Done"));
-$template->set('cancelbutton', _("Cancel"));
-$template->set('self_url', $self_url);
-$template->set('forminput', Util::formInput());
-$template->set('cacheid', htmlspecialchars($cacheid));
-$template->set('currdir', htmlspecialchars($currdir));
-$template->set('formid', htmlspecialchars($formid));
-$template->set('navlink', Gollem::directoryNavLink($currdir, Util::addParameter($self_url, array('cacheid' => $cacheid, 'formid' => $formid))));
+$t = new Gollem_Template();
+$t->set('addbutton', _("Add"));
+$t->set('donebutton', _("Done"));
+$t->set('cancelbutton', _("Cancel"));
+$t->set('self_url', $self_url);
+$t->set('forminput', Util::formInput());
+$t->set('cacheid', htmlspecialchars($cacheid));
+$t->set('currdir', htmlspecialchars($currdir));
+$t->set('formid', htmlspecialchars($formid));
+$t->set('navlink', Gollem::directoryNavLink($currdir, Util::addParameter($self_url, array('cacheid' => $cacheid, 'formid' => $formid))));
 if ($GLOBALS['conf']['backend']['backend_list'] == 'shown') {
-    $template->set('changeserver', Horde::link(htmlspecialchars(Auth::addLogoutParameters(Util::addParameter(Horde::applicationUrl('login.php'), array('url' => Util::addParameter(Horde::url('selectlist.php'), array('formid' => $formid)))), AUTH_REASON_LOGOUT)), _("Change Server")) . Horde::img('logout.png', _("Change Server"), null, $GLOBALS['registry']->getImageDir('horde')) . '</a>', true);
+    $t->set('changeserver', Horde::link(htmlspecialchars(Auth::addLogoutParameters(Util::addParameter(Horde::applicationUrl('login.php'), array('url' => Util::addParameter(Horde::url('selectlist.php'), array('formid' => $formid)))), AUTH_REASON_LOGOUT)), _("Change Server")) . Horde::img('logout.png', _("Change Server"), null, $GLOBALS['registry']->getImageDir('horde')) . '</a>', true);
 } else {
-    $template->set('changeserver', '', true);
+    $t->set('changeserver', '', true);
 }
 
-
-
 if (is_array($list) &&
     count($list) &&
     Gollem::checkPermissions('backend', PERMS_READ)) {
@@ -131,8 +137,16 @@ if (is_array($list) &&
             if (empty($icon_cache[$val['type']])) {
                 require_once 'Horde/MIME/Magic.php';
                 require_once 'Horde/MIME/Viewer.php';
-                require HORDE_BASE . '/config/mime_drivers.php';
-                require GOLLEM_BASE . '/config/mime_drivers.php';
+                if (is_callable(array('Horde', 'loadConfiguration'))) {
+                    $result = Horde::loadConfiguration('mime_drivers.php', array('mime_drivers', 'mime_drivers_map'), 'horde');
+                    extract($result);
+                    $result = Horde::loadConfiguration('mime_drivers.php', array('mime_drivers', 'mime_drivers_map'), 'gollem');
+                    $mime_drivers = array_merge_recursive($mime_drivers, $result['mime_drivers']);
+                    $mime_drivers_map = array_merge_recursive($mime_drivers_map, $result['mime_drivers_map']);
+                } else {
+                    require HORDE_BASE . '/config/mime_drivers.php';
+                    require GOLLEM_BASE . '/config/mime_drivers.php';
+                }
                 $icon_cache[$val['type']] = Horde::img(MIME_Viewer::getIcon(MIME_Magic::extToMIME($val['type'])), '', '', '');
             }
             $item['graphic'] = $icon_cache[$val['type']];
@@ -179,11 +193,11 @@ if (is_array($list) &&
         $entry[] = $item;
     }
 
-    $template->set('entry', $entry, true);
-    $template->set('nofiles', '', true);
+    $t->set('entry', $entry, true);
+    $t->set('nofiles', '', true);
 } else {
-    $template->set('nofiles', _("There are no files in this folder."), true);
+    $t->set('nofiles', _("There are no files in this folder."), true);
 }
 
-echo $template->fetch(GOLLEM_TEMPLATES . '/selectlist/selectlist.html');
+echo $t->fetch(GOLLEM_TEMPLATES . '/selectlist/selectlist.html');
 require $registry->get('templates', 'horde') . '/common-footer.inc';
