@@ -1,11 +1,13 @@
 <?php
 /**
- * $Horde: gollem/test.php,v 1.5.2.4 2007/01/02 13:54:52 jan Exp $
+ * $Horde: gollem/test.php,v 1.5.2.6 2009/01/06 15:23:53 jan Exp $
  *
- * Copyright 2003-2007 Michael Slusarz <slusarz@bigworm.colorado.edu>
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ *
+ * @author Michael Slusarz <slusarz@horde.org>
  */
 
 /* Include Horde's core.php file. */
@@ -15,17 +17,17 @@ include_once '../lib/core.php';
    package, in core.php. If String:: isn't defined, then we're not
    finding some critical libraries. */
 if (!class_exists('String')) {
-    echo '<br /><span style="color: red; font-size: 18px; font-weight: bold;">The Horde_Util package was not found. If PHP\'s error_reporting setting is high enough, there should be error messages printed above that may help you in debugging the problem. If you are simply missing these files, then you need to get the <a href="http://cvs.horde.org/cvs.php/framework">framework</a> module from <a href="http://horde.org/source/">Horde CVS</a>, and install the packages in it with the install-packages.php script.</span>';
+    echo '<br /><h2 style="color:red">The Horde_Util package was not found. If PHP\'s error_reporting setting is high enough and display_errors is on, there should be error messages printed above that may help you in debugging the problem. If you are simply missing these files, then you need to get the <a href="http://cvs.horde.org/cvs.php/framework">framework</a> module from <a href="http://www.horde.org/source/">Horde CVS</a>, and install the packages in it with the install-packages.php script.</h2>';
     exit;
 }
 
 /* Initialize the Horde_Test:: class. */
-if (!(@is_readable('../lib/Test.php'))) {
+if (!is_readable('../lib/Test.php')) {
     echo 'ERROR: You must install Horde before running this script.';
     exit;
 }
 require_once '../lib/Test.php';
-$horde_test = &new Horde_Test;
+$horde_test = new Horde_Test;
 
 /* Gollem version. */
 $module = 'Gollem';
@@ -50,6 +52,10 @@ $module_list = array(
         'descrip' => 'FTP Support',
         'error' => 'You need FTP support compiled into PHP if you plan to use the FTP VFS driver (see config/backends.php).'
     ),
+    'ssh2' => array(
+        'descrip' => 'SSH2 Support',
+        'error' => 'You need the SSH2 PECL module if you plan to use the SSH2 VFS driver (see config/backends.php).'
+    ),
 );
 
 /* Display versions of other Horde applications. */
@@ -57,14 +63,13 @@ $app_list = array(
     'horde' => array(
         'error' => 'Gollem requires Horde 3.0 or greater to operate.',
         'version' => '3.0'
-    )
+    ),
 );
-$app_output = $horde_test->requiredAppCheck($app_list);
 
 ?>
 <h1>Other Horde Applications</h1>
 <ul>
-    <?php echo $app_output ?>
+    <?php echo $horde_test->requiredAppCheck($app_list) ?>
 </ul>
 <?php
 
@@ -73,7 +78,11 @@ $php_info = $horde_test->getPhpVersionInformation();
 require TEST_TEMPLATES . 'php_version.inc';
 
 /* PEAR */
-$pear_list = array();
+$pear_list = array(
+    'HTTP_WebDAV_Server' => array(
+        'path' => 'HTTP/WebDAV/Server.php',
+        'error' => 'You do not have the HTTP_WebDAV_Server package installed on your system. This module is required to use browse the VFS using WebDAV.  See the INSTALL file for instructions on how to install the package.'    ),
+);
 
 /* Get the status output now. */
 $module_output = $horde_test->phpModuleCheck($module_list);
@@ -92,9 +101,16 @@ if (is_callable(array('VFS', 'getQuota'))) {
 /* Check for VFS drivers not present in Horde 3.0. */
 $smb_check = @include_once 'VFS/smb.php';
 if ($smb_check === false) {
-    $smb_output = '<font color="red"><strong>VFS library does NOT contain the <u>SMB</u> driver.</strong></font>';
+    $smb_output = '<font color="red"><strong>VFS library does NOT contain the SMB driver.</strong></font>';
 } else {
-    $smb_output = '<font color="green"><strong>VFS library contains the <u>SMB</u> driver.</strong></font>';
+    $smb_output = '<font color="green"><strong>VFS library contains the SMB driver.</strong></font>';
+}
+
+$ssh2_check = @include_once 'VFS/ssh2.php';
+if ($ssh2_check === false) {
+    $ssh2_output = '<font color="red"><strong>VFS library does NOT contain the SSH2 driver.</strong></font>';
+} else {
+    $ssh2_output = '<font color="green"><strong>VFS library contains the SSH2 driver.</strong></font>';
 }
 
 ?>
@@ -112,6 +128,7 @@ if ($smb_check === false) {
 <ul>
     <li><?php echo $quota_output ?></li>
     <li><?php echo $smb_output ?></li>
+    <li><?php echo $ssh2_output ?></li>
 </ul>
 
 <h1>PEAR Modules</h1>
